==> org.eclipse.xtext.builder.source_2.12.0.v20170519-0809.jar: org/eclipse/xtext/builder/debug/XtextBuildConsolePageParticipant.java <==
/*******************************************************************************
 * Copyright (c) 2017 itemis AG (http://www.itemis.eu) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.eclipse.xtext.builder.debug;

import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.ui.console.IConsole;
import org.eclipse.ui.console.IConsoleConstants;
import org.eclipse.ui.console.IConsolePageParticipant;
import org.eclipse.ui.console.actions.CloseConsoleAction;
import org.eclipse.ui.part.IPageBookViewPage;

/**
 * @author Christian Dietrich - Initial contribution and API
 * 
 * {@link IConsolePageParticipant} that adds a close action to Xtext Build Console
 * 
 * @since 2.12
 */
public class XtextBuildConsolePageParticipant implements IConsolePageParticipant {
	
	private CloseConsoleAction fCloseAction;

	@SuppressWarnings({ "unchecked", "rawtypes" })
	@Override
	public Object getAdapter(Class adapter) {
		return null;
	}

	@Override
	public void init(IPageBookViewPage page, IConsole console) {
		fCloseAction = new CloseConsoleAction(console);
		
		IToolBarManager manager = page.getSite().getActionBars().getToolBarManager();
		manager.appendToGroup(IConsoleConstants.LAUNCH_GROUP, fCloseAction);
	}

	@Override
	public void dispose() {
		deactivated();
	}

	@Override
	public void activated() {
	}

	@Override
	public void deactivated() {
	}

}

==> org.eclipse.xtext.builder.source_2.14.0.v20180523-0437.jar: org/eclipse/xtext/builder/debug/XtextBuildConsolePageParticipant.java <==
/*******************************************************************************
 * Copyright (c) 2017 itemis AG (http://www.itemis.eu) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.eclipse.xtext.builder.debug;

import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.ui.console.IConsole;
import org.eclipse.ui.console.IConsoleConstants;
import org.eclipse.ui.console.IConsolePageParticipant;
import org.eclipse.ui.console.actions.CloseConsoleAction;
import org.eclipse.ui.part.IPageBookViewPage;

/**
 * @author Christian Dietrich - Initial contribution and API
 * 
 * {@link IConsolePageParticipant} that adds a close action to Xtext Build Console
 * 
 * @since 2.12
 */
public class XtextBuildConsolePageParticipant implements IConsolePageParticipant {
	
	private CloseConsoleAction fCloseAction;

	@SuppressWarnings({ "rawtypes" })
	@Override
	public Object getAdapter(Class adapter) {
		return null;
	}

	@Override
	public void init(IPageBookViewPage page, IConsole console) {
		fCloseAction = new CloseConsoleAction(console);
		
		IToolBarManager manager = page.getSite().getActionBars().getToolBarManager();
		manager.appendToGroup(IConsoleConstants.LAUNCH_GROUP, fCloseAction);
	}

	@Override
	public void dispose() {
		deactivated();
	}

	@Override
	public void activated() {
	}

	@Override
	public void deactivated() {
	}

}
